# Airflow Hook for Greenplum

Install this package in the python environment with Airflow to use the Greenplum Hook.

Installation: `pip install airflowgp`

More about creating your own provider packages - https://airflow.apache.org/docs/apache-airflow-providers/index.html#how-to-create-your-own-provider
